<?php

/**
 * Plugin Name: CoreDash
 * Description: CoreDash plugin - coredash.app
 * Version: 7.3.24
 * Author: Arjen
 */

//zip -vr coredash.zip ./coredash


$plugin_name = 'coredash';


function coredash_register_custom_settings()
{
    add_options_page('CoreDash', 'CoreDash', 'manage_options', 'coredash_settings', 'coredash_render_custom_settings', 2);
}
add_action('admin_menu', 'coredash_register_custom_settings');


// Add settings link on plugin page
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'coredash_add_settings_link');

function coredash_add_settings_link($links)
{

    $url = esc_url(add_query_arg(
        'page',
        'coredash_render_custom_settings',
        get_admin_url() . 'options-general.php'
    ));

    $settings_link = '<a href="admin.php?page=coredash_settings">Settings</a>';
    array_unshift($links, $settings_link);
    return $links;
}



// Create settings page
function coredash_render_custom_settings()
{
?>
    <div class="wrap">
        <form method="post" action="options.php">
            <?php
            settings_fields('coredash_settings_group');
            do_settings_sections('coredash');
            submit_button();
            ?>
        </form>
    </div>
<?php
}

// Register settings
add_action('admin_init', 'coredash_register_settings');
function coredash_register_settings()
{

    register_setting('coredash_settings_group', 'coredash_api_key');
    register_setting('coredash_settings_group', 'coredash_auto_tagging');
    register_setting('coredash_settings_group', 'coredash_use_beta');
    register_setting('coredash_settings_group', 'coredash_timing');

    add_settings_section('coredash_main_section', 'Core/Dash RUm tracking for WordPress', 'coredash_section_text', 'coredash');

    add_settings_field('coredash_api_key', 'API Key', 'coredash_api_key_input', 'coredash', 'coredash_main_section');
    add_settings_field('coredash_auto_tagging', 'Smart auto tagging', 'coredash_auto_tagging_input', 'coredash', 'coredash_main_section');
    add_settings_field('coredash_use_beta', 'Beta features', 'coredash_use_beta_input', 'coredash', 'coredash_main_section');
    add_settings_field('coredash_timing', 'Timing', 'coredash_timing_input', 'coredash', 'coredash_main_section');
}



function coredash_section_text()
{
    echo '<p style="max-width: 1000px;">The Coredash plugin brings adds real time RUM tracking directly into your WordPress.
Set up the integration to start making informed decisions and delivering better experiences.</p>';
}

function coredash_timing_input()
{
    $coredash_timing = get_option('coredash_timing');
?>
    <select name="coredash_timing">
        <option value="async" <?php selected('async', $coredash_timing); ?>>Early Async</option>
        <option value="async_inject" <?php selected('async_inject', $coredash_timing); ?>>Early Injected</option>
        <option value="idle" <?php selected('idle', $coredash_timing); ?>>During Idle Time</option>
    </select>
    <p class="description" style="max-width: 800px;"><br />
       <b>Early Async</b> loads the script asynchronously as soon as possible. This is the best choice for collecting as much early data as possible. This is the recommended setting for debugging TTFB  <br /><br />
       <b>Early Injected</b> loads the script early but prioritizes other discoverable elements such as images. This is your best choice for collecting as much data as possible with little impact. <br /> <br />
       <b>During Idle Time</b> minimizes the Core Web Vitals on your pages. This is the recommended setting for long-term tracking.
    </p>
<?php
}

function coredash_use_beta_input()
{
    $coredash_use_beta = get_option('coredash_use_beta');
    echo '<input type="checkbox" name="coredash_use_beta" value="1"' . checked(1, $coredash_use_beta, false) . '> Use Beta';
    echo '<p class="description" style="max-width: 800px;">Use the beta version of the CoreWebVitals library.</p>';
}

function coredash_api_key_input()
{
    $api_key = get_option('coredash_api_key');
    echo '<input type="text" name="coredash_api_key" value="' . esc_attr($api_key) . '" class="regular-text">';
    echo '<p class="description" style="max-width: 800px;">Your API Key provided by Core/Dash</p>';

}

function coredash_auto_tagging_input()
{
    $auto_tagging = get_option('coredash_auto_tagging');
    echo '<input type="checkbox" name="coredash_auto_tagging" value="1"' . checked(1, $auto_tagging, false) . '> Enable auto tagging';
    echo '<p class="description" style="max-width: 800px;">Anonymously tag the page cache eligibility and logged-in status</p>';
}



function is_indexable()
{
    if (is_admin()) {
        return false;
    }
    return true;
}



// Add script to indexable pages
add_action('wp_head', 'coredash_add_script_to_head');
function coredash_add_script_to_head()
{
    if (is_indexable()) {
        $api_key = get_option('coredash_api_key');
        $auto_tagging = get_option('coredash_auto_tagging');
        $coredash_timing = get_option('coredash_timing');
        $coredash_use_beta = get_option('coredash_use_beta');


        $qs = '';
        if ($coredash_use_beta) {
            $qs = '?beta=true';
        }


        if ($api_key) {

            if (defined('DONOTCACHEPAGE') && DONOTCACHEPAGE == true) {
                echo '<script data-cfasync="false">window.__CWVL="DONOTCACHEPAGE";</script>';
            } else {
                if (isset($_COOKIE) && !empty($_COOKIE)) {
                    foreach ($_COOKIE as $name => $value) {
                        if (strpos($name, 'wordpress') === 0) {
                            echo '<script data-cfasync="false">window.__CWVL="PROBABLY_UNCACHED";</script>';

                            break;
                        }
                    }
                }
            }

            if ($auto_tagging) {
                if (is_user_logged_in()) {
                    if (current_user_can('administrator')) {
                        $li = '2';
                    } else {
                        $li = '1';
                    }
                } else {
                    $li = '0';
                }

                echo '<script data-cfasync="false">window.__CWVLI=' . $li . ';</script>';
            }


            $rum_url = 'https://rum.corewebvitals.io/cwv/' . esc_attr($api_key) . '.js' . $qs;

            if ($coredash_timing == 'async_inject') {
                echo '<script data-cfasync="false">var script = document.createElement("script");script.src = "' . $rum_url . '";document.documentElement.appendChild(script);</script>';
            } else if ($coredash_timing == 'idle') {
                echo '<script data-cfasync="false">var _cwv_cbf = window.requestIdleCallback || function(cb) {setTimeout(cb, 0);};window.addEventListener("load", function() {_cwv_cbf(function() {var script = document.createElement("script");script.src = "' . $rum_url . '";document.body.appendChild(script);});});</script>';
            } else {
                echo '<script data-cfasync="false" async src="' . $rum_url . '"></script>';
            }
        }
    }
}
?>